==> jc-1.4.0.tar.gz: java/awt/im/InputMethodHighlight.h <==
// public class java.awt.im.InputMethodHighlight

// class file dependencies
// @dep_class aa8b96da6d527d34 java_awt_im_InputMethodHighlight
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_im_InputMethodHighlight_H_
#define _JC_java_awt_im_InputMethodHighlight_H_

// Forward structure declarations
struct _jc_java_awt_im_InputMethodHighlight$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_java_awt_im_InputMethodHighlight$sub_refs	_jc_java_awt_im_InputMethodHighlight$sub_refs;
typedef struct _jc_java_awt_im_InputMethodHighlight$sub_nonrefs	_jc_java_awt_im_InputMethodHighlight$sub_nonrefs;
typedef struct _jc_java_awt_im_InputMethodHighlight$refs	_jc_java_awt_im_InputMethodHighlight$refs;
typedef struct _jc_java_awt_im_InputMethodHighlight$nonrefs	_jc_java_awt_im_InputMethodHighlight$nonrefs;
typedef struct _jc_java_awt_im_InputMethodHighlight$object	_jc_java_awt_im_InputMethodHighlight$object;

typedef struct _jc_java_awt_im_InputMethodHighlight$fields_struct	_jc_java_awt_im_InputMethodHighlight$fields_struct;
typedef const struct _jc_java_awt_im_InputMethodHighlight$vmethods	_jc_java_awt_im_InputMethodHighlight$vmethods;
typedef const struct _jc_java_awt_im_InputMethodHighlight$vtable	_jc_java_awt_im_InputMethodHighlight$vtable;
typedef const struct _jc_java_awt_im_InputMethodHighlight$vtype	_jc_java_awt_im_InputMethodHighlight$vtype;

// Class fields structure
struct _jc_java_awt_im_InputMethodHighlight$fields_struct {
	struct _jc_java_awt_im_InputMethodHighlight$object	*SELECTED__5fCONVERTED__5fTEXT__5fHIGHLIGHT;
	struct _jc_java_awt_im_InputMethodHighlight$object	*SELECTED__5fRAW__5fTEXT__5fHIGHLIGHT;
	struct _jc_java_awt_im_InputMethodHighlight$object	*UNSELECTED__5fCONVERTED__5fTEXT__5fHIGHLIGHT;
	struct _jc_java_awt_im_InputMethodHighlight$object	*UNSELECTED__5fRAW__5fTEXT__5fHIGHLIGHT;
	jint	CONVERTED__5fTEXT;
	jint	RAW__5fTEXT;
};
extern _jc_java_awt_im_InputMethodHighlight$fields_struct _jc_java_awt_im_InputMethodHighlight$class_fields;

// Constructors
extern void _jc_java_awt_im_InputMethodHighlight$method$_init$9ff456f5359e4cdd(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *, jboolean, jint);
extern void _jc_java_awt_im_InputMethodHighlight$method$_init$76e985635cbc51a1(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *, jboolean, jint, jint);
extern void _jc_java_awt_im_InputMethodHighlight$method$_init$374ca34ea2450103(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *, jboolean, jint, jint, struct _jc_object *);

// Virtual methods
extern jint _jc_java_awt_im_InputMethodHighlight$method$getState$5706f9b95e7ff8b7(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *);
extern struct _jc_object *_jc_java_awt_im_InputMethodHighlight$method$getStyle$5728ea1001b34f23(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *);
extern jint _jc_java_awt_im_InputMethodHighlight$method$getVariation$ca53c5d614404a61(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *);
extern jboolean _jc_java_awt_im_InputMethodHighlight$method$isSelected$b1d4e2f0277c017b(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_im_InputMethodHighlight$method_info$getState$5706f9b95e7ff8b7;
extern _jc_method _jc_java_awt_im_InputMethodHighlight$method_info$getStyle$5728ea1001b34f23;
extern _jc_method _jc_java_awt_im_InputMethodHighlight$method_info$getVariation$ca53c5d614404a61;
extern _jc_method _jc_java_awt_im_InputMethodHighlight$method_info$isSelected$b1d4e2f0277c017b;

// Static methods
extern void _jc_java_awt_im_InputMethodHighlight$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_im_InputMethodHighlight$vmethods {
	jint	(*getState$5706f9b95e7ff8b7)(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *);
	struct _jc_object	*(*getStyle$5728ea1001b34f23)(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *);
	jint	(*getVariation$ca53c5d614404a61)(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *);
	jboolean	(*isSelected$b1d4e2f0277c017b)(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *);
};

// Vtable
struct _jc_java_awt_im_InputMethodHighlight$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_im_InputMethodHighlight$vmethods	java_awt_im_InputMethodHighlight;
};

// Vtype
struct _jc_java_awt_im_InputMethodHighlight$vtype {
	_jc_type			type;
	_jc_java_awt_im_InputMethodHighlight$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_im_InputMethodHighlight$sub_refs {
	struct _jc_object	*style;
};

// Reference instance fields (object)
struct _jc_java_awt_im_InputMethodHighlight$refs {
    _jc_java_awt_im_InputMethodHighlight$sub_refs	java_awt_im_InputMethodHighlight;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_im_InputMethodHighlight$sub_nonrefs {
	jboolean	selected;
	jint	state;
	jint	variation;
};

// Non-reference instance fields (object)
struct _jc_java_awt_im_InputMethodHighlight$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_im_InputMethodHighlight$sub_nonrefs	java_awt_im_InputMethodHighlight;
};

// Object instance structure
struct _jc_java_awt_im_InputMethodHighlight$object {
	_jc_java_awt_im_InputMethodHighlight$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_im_InputMethodHighlight$vtype	*vtype;
	_jc_java_awt_im_InputMethodHighlight$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_im_InputMethodHighlight$vtype _jc_java_awt_im_InputMethodHighlight$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_im_InputMethodHighlight, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_im_InputMethodHighlight$class_object;

#endif	/* _JC_java_awt_im_InputMethodHighlight_H_ */

==> jc-1.4.6.tar.gz: java/awt/im/InputMethodHighlight.h <==
// public class java.awt.im.InputMethodHighlight

// class file dependencies
// @dep_class aa8b96da6d527d34 java_awt_im_InputMethodHighlight
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_im_InputMethodHighlight_H_
#define _JC_java_awt_im_InputMethodHighlight_H_

// Forward structure declarations
struct _jc_java_awt_im_InputMethodHighlight$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_java_awt_im_InputMethodHighlight$sub_refs	_jc_java_awt_im_InputMethodHighlight$sub_refs;
typedef struct _jc_java_awt_im_InputMethodHighlight$sub_nonrefs	_jc_java_awt_im_InputMethodHighlight$sub_nonrefs;
typedef struct _jc_java_awt_im_InputMethodHighlight$refs	_jc_java_awt_im_InputMethodHighlight$refs;
typedef struct _jc_java_awt_im_InputMethodHighlight$nonrefs	_jc_java_awt_im_InputMethodHighlight$nonrefs;
typedef struct _jc_java_awt_im_InputMethodHighlight$object	_jc_java_awt_im_InputMethodHighlight$object;

typedef struct _jc_java_awt_im_InputMethodHighlight$fields_struct	_jc_java_awt_im_InputMethodHighlight$fields_struct;
typedef const struct _jc_java_awt_im_InputMethodHighlight$vmethods	_jc_java_awt_im_InputMethodHighlight$vmethods;
typedef const struct _jc_java_awt_im_InputMethodHighlight$vtable	_jc_java_awt_im_InputMethodHighlight$vtable;
typedef const struct _jc_java_awt_im_InputMethodHighlight$vtype	_jc_java_awt_im_InputMethodHighlight$vtype;

// Class fields structure
struct _jc_java_awt_im_InputMethodHighlight$fields_struct {
	struct _jc_java_awt_im_InputMethodHighlight$object	*SELECTED__5fCONVERTED__5fTEXT__5fHIGHLIGHT;
	struct _jc_java_awt_im_InputMethodHighlight$object	*SELECTED__5fRAW__5fTEXT__5fHIGHLIGHT;
	struct _jc_java_awt_im_InputMethodHighlight$object	*UNSELECTED__5fCONVERTED__5fTEXT__5fHIGHLIGHT;
	struct _jc_java_awt_im_InputMethodHighlight$object	*UNSELECTED__5fRAW__5fTEXT__5fHIGHLIGHT;
	jint	CONVERTED__5fTEXT;
	jint	RAW__5fTEXT;
};
extern _jc_java_awt_im_InputMethodHighlight$fields_struct _jc_java_awt_im_InputMethodHighlight$class_fields;

// Constructors
extern void _jc_java_awt_im_InputMethodHighlight$method$_init$9ff456f5359e4cdd(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *, jboolean, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_im_InputMethodHighlight$method$_init$76e985635cbc51a1(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *, jboolean, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_im_InputMethodHighlight$method$_init$374ca34ea2450103(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *, jboolean, jint, jint, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_im_InputMethodHighlight$method$getState$5706f9b95e7ff8b7(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_awt_im_InputMethodHighlight$method$getStyle$5728ea1001b34f23(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_im_InputMethodHighlight$method$getVariation$ca53c5d614404a61(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_im_InputMethodHighlight$method$isSelected$b1d4e2f0277c017b(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_im_InputMethodHighlight$method_info$getState$5706f9b95e7ff8b7;
extern _jc_method _jc_java_awt_im_InputMethodHighlight$method_info$getStyle$5728ea1001b34f23;
extern _jc_method _jc_java_awt_im_InputMethodHighlight$method_info$getVariation$ca53c5d614404a61;
extern _jc_method _jc_java_awt_im_InputMethodHighlight$method_info$isSelected$b1d4e2f0277c017b;

// Static methods
extern void _jc_java_awt_im_InputMethodHighlight$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_im_InputMethodHighlight$vmethods {
	jint	(*getState$5706f9b95e7ff8b7)(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getStyle$5728ea1001b34f23)(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *) _JC_JCNI_ATTR;
	jint	(*getVariation$ca53c5d614404a61)(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *) _JC_JCNI_ATTR;
	jboolean	(*isSelected$b1d4e2f0277c017b)(_jc_env *, struct _jc_java_awt_im_InputMethodHighlight$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_im_InputMethodHighlight$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_im_InputMethodHighlight$vmethods	java_awt_im_InputMethodHighlight;
};

// Vtype
struct _jc_java_awt_im_InputMethodHighlight$vtype {
	_jc_type			type;
	_jc_java_awt_im_InputMethodHighlight$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_im_InputMethodHighlight$sub_refs {
	struct _jc_object	*style;
};

// Reference instance fields (object)
struct _jc_java_awt_im_InputMethodHighlight$refs {
    _jc_java_awt_im_InputMethodHighlight$sub_refs	java_awt_im_InputMethodHighlight;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_im_InputMethodHighlight$sub_nonrefs {
	jboolean	selected;
	jint	state;
	jint	variation;
};

// Non-reference instance fields (object)
struct _jc_java_awt_im_InputMethodHighlight$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_im_InputMethodHighlight$sub_nonrefs	java_awt_im_InputMethodHighlight;
};

// Object instance structure
struct _jc_java_awt_im_InputMethodHighlight$object {
	_jc_java_awt_im_InputMethodHighlight$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_im_InputMethodHighlight$vtype	*vtype;
	_jc_java_awt_im_InputMethodHighlight$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_im_InputMethodHighlight$vtype _jc_java_awt_im_InputMethodHighlight$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_im_InputMethodHighlight, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_im_InputMethodHighlight$class_object;

#endif	/* _JC_java_awt_im_InputMethodHighlight_H_ */
